%GEN_CYL generate an image (3D array) with one cylinder
%
%----------------------------------------------------------------------------
% Usage :
%--------
%	IM0=gen_cyl(P0,D0,R0,X,Y,Z)
%
% Input : 
%--------
%	P0 :	[p0x,p0y,p0z], a point of the axis
%	D0 :	[d0x,d0y,d0z], direction of the axis
%	R0 :	radius
%	X,Y,Z :	coordinates generated by gen_grid(X0,[dx,dy,dz],[nx,ny,nz])
%             
% Output :    
%---------
%	IM0 :	image (3D array)
%
%---------------------------------------------------------------------------	
%	
% OCTAVE : OK 
% MATLAB : OK
%
%---------------------------------------------------------------------------
% AUTHOR : LG
%
% Modification :
%	18/06/2019 : first version
%
%===========================================================================
function IM0=gen_cyl(P0,D0,R0,X,Y,Z)

p0x = P0(1);p0y = P0(2);p0z = P0(3);
D0 = D0/norm(D0);
DX = D0(1);DY = D0(2); DZ = D0(3);


P0Mx = X - p0x; 
P0My = Y - p0y;
P0Mz = Z - p0z;
P0MsD0 = P0Mx*DX + P0My * DY + P0Mz * DZ;

M0Mx = P0Mx - P0MsD0*DX;
M0My = P0My - P0MsD0*DY;
M0Mz = P0Mz - P0MsD0*DZ;
  

D =  sqrt(M0Mx.*M0Mx + M0My.*M0My + M0Mz.*M0Mz);
IM0 = zeros(size(X),'int8');

IM0(D<R0) = 1;
 

