%GEN_GRID generate 3D arrays of voxels centers coordinates X, Y and Z
%
% X, Y, and Z are generated with ndgrid
%
%===========================================================================
%
% Usage :
%-------
%	[X,Y,Z] = gen_grid(P0,D0,N0)
%
% Input : 
%--------
%	P0 :	[p0x,p0y,p0z], lower coordinates of unit-cell corners
%	D0 :	[DX,DY,DZ], dimension of the unit-cell
%	N0 :	[NX,NY,NZ], number of  voxels per dimension
%             
% Output :    
%---------
%	X, Y, Z : coordinates of voxels centers, 3D arrays
%
%---------------------------------------------------------------------------	
%	
% OCTAVE : OK 
% MATLAB : OK
%
%---------------------------------------------------------------------------
% AUTHOR : LG
%
% Modification :
%	18/06/2019 : first version
%
%===========================================================================
function [X,Y,Z] = gen_grid(P0,D0,N0)

p0x = P0(1);p0y = P0(2);p0z = P0(3);
DX = D0(1);DY = D0(2); DZ = D0(3);
nx = N0(1);ny = N0(2); nz = N0(3);
dx = DX/nx;dy = DY/ny; dz = DZ/nz;

[X,Y,Z]=ndgrid([0.5*dx:dx:DX-0.5*dx],[0.5*dy:dy:DY-0.5*dy],[0.5*dz:dz:DZ-0.5*dz]);

X=X+p0x;
Y=Y+p0y;
Z=Z+p0z;


