%SAVE_COMPOSITE_VOXELS : save composite voxels for AMITEX_FFTP
%
%	the description of composite voxels gathered in a cell of objects
%
%	of class Composite_Material is converted in a structure of files 
%
%	and diretories compatible with AMITEX_FFTP
%
%===========================================================================
%
% Usage :
%--------
%	save_composite_voxels(MatComp,Rep )
%
%	with : 
%
%       MatComp = Composite_Material(position,zone,nzone,loi,phases,fv,...
%                                normale,direction,surface)
%
%       type help Composite_Material for more information
%
% Input :
%--------
%	MatComp	:	cell of objects of class Material_Composite 
%
%                	Type help Material_Composite for a description        
%
%	Rep	:	name of the directory including the generated files
%
%
% Output : 	Rep is generated
%---------	see AMITEX_FFTP doc for a description of the different 
%               directories and files
%
%---------------------------------------------------------------------------	
%	
% OCTAVE : OK
%          
% MATLAB : OK
%
%---------------------------------------------------------------------------
% AUTHOR : A.MARANO, L.GELEBART 
%          (initially 'Creation_fichiers_composites.m' by A.MARANO)
%
% Modification :
%	17/12/2019 : first version in microgen_fft
%	06/03/2020 : correction fopen for octave
%
%===========================================================================
function save_composite_voxels(MatComp,Rep )

global octave;

% Création du répertoire contenant toute les données
%--------------------------------------------------------------------------
%system(['mkdir ',Rep]);
mkdir(Rep);

%% Ecriture de la liste des matériaux composites
nfich = strcat(Rep,'/list_composite_materials.txt');
nfich
%fidlist = fopen(nfich,'wt','b','US-ASCII') ; % LG : pb with Octave
fidlist = fopen(nfich,'w');

for i = 1:size(MatComp,1)
    
    nZones = size(MatComp{i}.Zone,1);
    
        
    %% Création du sous-répertoire propre au matériau composite i
    %  Ecriture du fichier liste_composite_materials
    %------------------------------------------------------------------
    Ss_rep = strcat(Rep,'/rep');
    Nphases = length(MatComp{i}.Phases);
    Ligne ='';
    for j = 1:Nphases
        Ss_rep = strcat(Ss_rep,'_',num2str(MatComp{i}.Phases(j)));
        Ligne  = [Ligne,num2str(MatComp{i}.Phases(j)),' '];
    end
    
    Ligne = [Ligne,' ',MatComp{i}.Law]; %#ok<*AGROW>
    fprintf(fidlist,'%s \n',Ligne);
    
    %system(['mkdir ',Ss_rep]);
    mkdir(Ss_rep);
    %Ss_rep = [Ss_rep,'/'];
    Ss_rep = strcat(Ss_rep,'/');
    %% Ecriture du fichier binaire des positions linéarisée
    %  des voxels du matériau i
    %------------------------------------------------------------------
    nfich = strcat(Ss_rep,'pos.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','unsigned_long');
    fwrite(fid,MatComp{i}.Position,'int64',0,'b');
    fclose(fid);
    
    %% Ecriture des fichiers binaires des numéros de zone homogènes de
    %  chaque phase
    %------------------------------------------------------------------
    for j = 1:Nphases
        
        nfich = strcat(Ss_rep,'zone',num2str(j),'.bin');fid = fopen(nfich, 'w');
        fprintf(fid,'%s \n',num2str(nZones));
        fprintf(fid,'%s \n','unsigned_long');
        fwrite(fid,MatComp{i}.Zone(:,j),'int64',0,'b');
        fclose(fid);
    end
    
    %% Ecriture des fichiers binaires des fractions volumiques
    %  de chaque phase
    %------------------------------------------------------------------
    
    for j = 1:Nphases
        
        nfich = strcat(Ss_rep ,'fv',num2str(j),'.bin');fid = fopen(nfich, 'w');
        fprintf(fid,'%s \n',num2str(nZones));
        fprintf(fid,'%s \n','double');
        fwrite(fid,MatComp{i}.Fv(:,j),'double',0,'b');
        fclose(fid);
    end
    
    %% Ecriture des fichiers binaires des vecteurs d'orientation de l'interface
    %------------------------------------------------------------------
    
    nfich = strcat(Ss_rep,'N12x.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','double');
    fwrite(fid,MatComp{i}.Normal(:,1),'double',0,'b');
    
    fclose(fid);
    
    nfich = strcat(Ss_rep,'N12y.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','double');
    fwrite(fid,MatComp{i}.Normal(:,2),'double',0,'b');
    fclose(fid);
    
    nfich = strcat(Ss_rep,'N12z.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','double');
    fwrite(fid,MatComp{i}.Normal(:,3),'double',0,'b');
    fclose(fid);
    
    nfich = strcat(Ss_rep,'Tx.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','double');
    fwrite(fid,MatComp{i}.Direction(:,1),'double',0,'b');
    fclose(fid);
    
    nfich = strcat(Ss_rep,'Ty.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','double');
    fwrite(fid,MatComp{i}.Direction(:,2),'double',0,'b');
    fclose(fid);
    
    nfich = strcat(Ss_rep,'Tz.bin');fid = fopen(nfich, 'w');
    fprintf(fid,'%s \n',num2str(nZones));
    fprintf(fid,'%s \n','double');
    fwrite(fid,MatComp{i}.Direction(:,3),'double',0,'b');
    fclose(fid);
    
    %% Ecriture des fichiers surfaces d'interface (optionnels)
    %------------------------------------------------------------------
    if ~isempty(MatComp{i}.Surface)
        for j = 1:(Nphases-1)
            nfich = strcat(Ss_rep,'S',num2str(j),num2str(j+1),'.bin');fid = fopen(nfich, 'w');
            fprintf(fid,'%s \n',num2str(nZones));
            fprintf(fid,'%s \n','double');
            fwrite(fid,MatComp{i}.Surface(:,j),'double',0,'b');
            fclose(fid);
        end
    end
    
end

fclose(fidlist);

end

